pub enum BackendJobs {
Limited(NonZero<usize>),
UnlimitedOr32,
}Variants
Limited(NonZero<usize>)
The number of backend jobs has a static limit.
UnlimitedOr32
The number of backend jobs is either unlimited if there’s an inherited jobserver,
or limited to 32 if there’s no inherited jobserver.
This variant exists only to preserve the historical behavior.
FIXME: Just use thread::available_parallelism as the default static limit.
Implementations